pulp-certguard
==============

.. image:: https://travis-ci.org/pulp/pulp-certguard.svg?branch=master
   :target: https://travis-ci.org/pulp/pulp-certguard

A Pulp plugin that provides an X.509 capable ``ContentGuard`` for pulpcore. Instances of
``X509CertGuard`` are useful for requiring clients to submit a certificate proving their entitlement
to content before receiving the content.

For more information, please see the `documentation <https://pulp-certguard.readthedocs.io/en/
latest/>`_ or the `Pulp project page <https://pulpproject.org>`_.
